using UnityEngine;
using System.Collections;

public class Controls : MonoBehaviour {

	public PackedSprite playerSprite;
	public GameObject slideCollider;
	public float moveSpeed = 4f;
	public float slideSpeed = 6f;
	public float jumpHeight = 10f;
	public float doubleJumpHeight = 10f;
	
	public HUDManager hudManager;
	
	private bool playerDead = false;
	private Transform thisTransform;
	private bool moving;
	private bool movingLeft = false;
	private bool movingRight = false;
	private bool wasMovingLeft;
	private float baseMoveSpeed;
	private bool doubleJump = false;
	
	private bool grounded = false;
	private Vector3 raycastDir = -Vector3.up;
	private float movement;
	
	private Vector3 downForce;
	
	private int moveDir;
	
	private bool sliding = false;
	private int slideTime;
	
	void Awake() {
		thisTransform = transform;
		baseMoveSpeed = moveSpeed;
	}
	
	// Use this for initialization
	void Start() {
		downForce = new Vector3(0f,-10f,0f);
		Physics.gravity = new Vector3(0f, -25f, 0f);
	}
	
	/* ============================== KEYBOARD INPUT ============================== */
	void Update() {
		if(!playerDead) {
			if(Input.GetKeyDown("space")) {
				if(grounded) {
					rigidbody.velocity = new Vector3(0f,jumpHeight,0f);
					AnimateJump();
				}
				
				if(!grounded && !doubleJump) {
					doubleJump = true;
					rigidbody.velocity = new Vector3(0f,doubleJumpHeight,0f);
					AnimateJump();
				}
			}
			
			if(Input.GetKeyDown("left ctrl")) {
				if(!sliding) {
					StartCoroutine(AnimateSlide());
				}
			}
						
			if(Input.GetKey("left")) {
				moveDir = -1;
				wasMovingLeft = true;
				
				if(!movingLeft) {
					movingLeft = true;
					movingRight = false;
					AnimateWalk();
				}
			}
			
			else if(Input.GetKey("right")) {
				moveDir = 1;
				wasMovingLeft = false;
				
				if(!movingRight) {
					movingLeft = false;
					movingRight = true;
					AnimateWalk();
				}
			}
			else {
				if(!sliding) {
					moveDir = 0;
				}
				movingLeft = false;
				movingRight = false;
			}
			
		}
	}
	
	/* ============================== ANIMATE WALK ============================== */
	void AnimateWalk() {
		if(movingLeft) {
			if(grounded) {
				if(!sliding) {
					playerSprite.PlayAnim(0); // walk left animation
				}
			}
			else {
				if(!sliding) {
					playerSprite.PlayAnim(2); // jump left animation
				}
			}
			
			if(sliding) {
				playerSprite.PlayAnim(4); // slide left animation
			}
		}
		else {
			if(grounded) {
				if(!sliding) {
					playerSprite.PlayAnim(1); // walk right animation
				}
			}
			else {
				if(!sliding) {
					playerSprite.PlayAnim(3); // jump right animation
				}
			}
			
			if(sliding) {
				playerSprite.PlayAnim(5); // slide right animation
			}
		}
	}
	
	/* ============================== ANIMATE JUMP ============================== */
	void AnimateJump() {
		if(movingLeft) {
			playerSprite.PlayAnim(2); // jump left animation
		}
		else {
			playerSprite.PlayAnim(3); // jump right animation
		}
	}
	
	/* ============================== ANIMATE SLIDE ============================== */
	IEnumerator AnimateSlide() {
		if(!sliding) {
			sliding = true;
			moveSpeed = slideSpeed;
			slideCollider.active = true;
			
			if(wasMovingLeft) {
				moveDir = -1;
				//wasMovingLeft = true;
				playerSprite.PlayAnim(4); // slide left animation
			}
			else {
				moveDir = 1;
				//wasMovingLeft = false;
				playerSprite.PlayAnim(5); // slide right animation
			}
			
			slideTime = 0;
			while(slideTime < 3) {
				slideTime++;
				yield return new WaitForSeconds(0.1f);
			}
		}
		sliding = false;
		moveSpeed = baseMoveSpeed;
		slideCollider.active = false;
		
		AnimateWalk();
	}
	
	/* ============================== MOVE PLAYER ============================== */
	void FixedUpdate () {
		rigidbody.AddForce(downForce);
		
		if(!playerDead) {
			movement = moveDir * moveSpeed;
			movement *= Time.deltaTime;
			thisTransform.Translate(movement,0.0f, 0.0f);
			
			if(movement == 0 && !sliding) {				
				if(wasMovingLeft) {
					playerSprite.PlayAnim(2); // stand left animation
				}
				else {
					playerSprite.PlayAnim(3); // stand right animation
				}
			}
		}	
		
		// keep player locked to 0 on the Z axis
		if(thisTransform.position.z > 0f || thisTransform.position.z < 0f) {
			thisTransform.position = new Vector3(thisTransform.position.x,thisTransform.position.y, 0f);
		}
		
		// raycast check to see if the player is standing on the ground
		if (Physics.Raycast(thisTransform.position, raycastDir, 0.5f)) {
			if(!grounded) {
				grounded = true;
				doubleJump = false;
				AnimateWalk();
			}
		}
		else {
			grounded = false;
		}
		
		//Debug.DrawLine (thisTransform.position, new Vector3 (0f,-0.5f,0f), Color.red);
	}
	
	void OnCollisionEnter(Collision collision) {
		if(collision.gameObject.tag == "Enemy" && !sliding) {
			KillMe();
		}
	}
	
	void KillMe() {
		playerDead = true;
		thisTransform.position = new Vector3(-10f,0f,0f);
		
		hudManager.GameOver();
	}
}
